@@ -22,14 +22,14 @@
 
 #include <tqvaluelist.h>
 
-namespace KIO {
+namespace TDEIO {
   class Job;
 }
 
 class K3bCddbHttpQuery : public K3bCddbQuery
 {
-  Q_OBJECT
   TQ_OBJECT
+  
 
  public:
   K3bCddbHttpQuery( TQObject* parent = 0, const char* name = 0 );
@@ -42,8 +42,8 @@ class K3bCddbHttpQuery : public K3bCddbQuery
  protected slots:
   void doQuery();
   void doMatchQuery();
-  void slotResult( KIO::Job* );
-  void slotData( KIO::Job*, const TQByteArray& data );
+  void slotResult( TDEIO::Job* );
+  void slotData( TDEIO::Job*, const TQByteArray& data );
 
  private:
   void performCommand( const TQString& );
