@@ -207,12 +207,12 @@ bool K3bExternalEncoder::initEncoderInternal( const TQString& extension )
   d->process->setSplitStdout(true);
   d->process->setRawStdin(true);
 
-  connect( d->process, TQT_SIGNAL(processExited(TDEProcess*)),
-	   this, TQT_SLOT(slotExternalProgramFinished(TDEProcess*)) );
-  connect( d->process, TQT_SIGNAL(stderrLine(const TQString&)),
-	   this, TQT_SLOT(slotExternalProgramOutputLine(const TQString&)) );
-  connect( d->process, TQT_SIGNAL(stdoutLine(const TQString&)),
-	   this, TQT_SLOT(slotExternalProgramOutputLine(const TQString&)) );
+  connect( d->process, TQ_SIGNAL(processExited(TDEProcess*)),
+	   this, TQ_SLOT(slotExternalProgramFinished(TDEProcess*)) );
+  connect( d->process, TQ_SIGNAL(stderrLine(const TQString&)),
+	   this, TQ_SLOT(slotExternalProgramOutputLine(const TQString&)) );
+  connect( d->process, TQ_SIGNAL(stdoutLine(const TQString&)),
+	   this, TQ_SLOT(slotExternalProgramOutputLine(const TQString&)) );
 
 
   // create the commandline
