@@ -29,7 +29,7 @@ class TQListViewItem;
 
 class K3bAudioMetainfoRenamerPluginWidget : public TQWidget, public K3bProjectPluginGUIBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
@@ -62,7 +62,7 @@ class K3bAudioMetainfoRenamerPluginWidget : public TQWidget, public K3bProjectPl
 
 class K3bAudioMetainfoRenamerPlugin : public K3bProjectPlugin
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
