@@ -32,16 +32,16 @@
 #include <k3bapplication.h>
 #include <k3bmediacache.h>
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kurlrequester.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kstdguiitem.h>
 #include <kguiitem.h>
 #include <kiconloader.h>
-#include <kconfig.h>
-#include <kio/global.h>
+#include <tdeconfig.h>
+#include <tdeio/global.h>
 #include <kurl.h>
 #include <kinputdialog.h>
 #include <kurldrag.h>
@@ -102,24 +102,24 @@ K3bIsoImageWritingDialog::K3bIsoImageWritingDialog( TQWidget* parent, const char
   m_writerSelectionWidget->setSupportedWritingApps( K3b::GROWISOFS );
   m_writingModeWidget->setSupportedModes( K3b::DAO|K3b::WRITING_MODE_INCR_SEQ|K3b::WRITING_MODE_RES_OVWR );
 
-  m_md5Job = new K3bMd5Job( 0, TQT_TQOBJECT(this) );
-  connect( m_md5Job, TQT_SIGNAL(finished(bool)),
-	   this, TQT_SLOT(slotMd5JobFinished(bool)) );
-  connect( m_md5Job, TQT_SIGNAL(percent(int)),
-	   this, TQT_SLOT(slotMd5JobPercent(int)) );
+  m_md5Job = new K3bMd5Job( 0, this );
+  connect( m_md5Job, TQ_SIGNAL(finished(bool)),
+	   this, TQ_SLOT(slotMd5JobFinished(bool)) );
+  connect( m_md5Job, TQ_SIGNAL(percent(int)),
+	   this, TQ_SLOT(slotMd5JobPercent(int)) );
 
   updateImageSize( imagePath() );
 
-  connect( m_writerSelectionWidget, TQT_SIGNAL(writerChanged()),
-	   this, TQT_SLOT(slotWriterChanged()) );
-  connect( m_writerSelectionWidget, TQT_SIGNAL(writingAppChanged(int)),
-	   this, TQT_SLOT(slotWriterChanged()) );
-  connect( m_writingModeWidget, TQT_SIGNAL(writingModeChanged(int)),
-	   this, TQT_SLOT(slotWriterChanged()) );
-  connect( m_editImagePath, TQT_SIGNAL(textChanged(const TQString&)),
-	   this, TQT_SLOT(updateImageSize(const TQString&)) );
-  connect( m_checkDummy, TQT_SIGNAL(toggled(bool)),
-	   this, TQT_SLOT(slotWriterChanged()) );
+  connect( m_writerSelectionWidget, TQ_SIGNAL(writerChanged()),
+	   this, TQ_SLOT(slotWriterChanged()) );
+  connect( m_writerSelectionWidget, TQ_SIGNAL(writingAppChanged(int)),
+	   this, TQ_SLOT(slotWriterChanged()) );
+  connect( m_writingModeWidget, TQ_SIGNAL(writingModeChanged(int)),
+	   this, TQ_SLOT(slotWriterChanged()) );
+  connect( m_editImagePath, TQ_SIGNAL(textChanged(const TQString&)),
+	   this, TQ_SLOT(updateImageSize(const TQString&)) );
+  connect( m_checkDummy, TQ_SIGNAL(toggled(bool)),
+	   this, TQ_SLOT(slotWriterChanged()) );
 }
 
 
@@ -134,7 +134,7 @@ void K3bIsoImageWritingDialog::init()
   if( !d->imageForced ) {
     // when opening the dialog first the default settings are loaded and afterwards we set the
     // last written image because that's what most users want
-    KConfig* c = k3bcore->config();
+    TDEConfig* c = k3bcore->config();
     c->setGroup( configGroup() );
     TQString image = c->readPathEntry( "last written image" );
     if( TQFile::exists( image ) )
@@ -149,14 +149,14 @@ void K3bIsoImageWritingDialog::setupGui()
 
   // image
   // -----------------------------------------------------------------------
-  TQGroupBox* groupImageUrl = new TQGroupBox( 1, Qt::Horizontal, i18n("Image to Burn"), frame );
+  TQGroupBox* groupImageUrl = new TQGroupBox( 1, TQt::Horizontal, i18n("Image to Burn"), frame );
   m_editImagePath = new KURLRequester( groupImageUrl );
   m_editImagePath->setMode( KFile::File|KFile::ExistingOnly );
   m_editImagePath->setCaption( i18n("Choose Image File") );
   m_editImagePath->setFilter( i18n("*.iso *.ISO|ISO9660 Image Files") + "\n"
 			      + i18n("*|All Files") );
 
-  connect( m_editImagePath->lineEdit(), TQT_SIGNAL( textChanged ( const TQString & ) ), this,  TQT_SLOT( slotWriterChanged() ) );
+  connect( m_editImagePath->lineEdit(), TQ_SIGNAL( textChanged ( const TQString & ) ), this,  TQ_SLOT( slotWriterChanged() ) );
 
   // image info
   // -----------------------------------------------------------------------
@@ -170,8 +170,8 @@ void K3bIsoImageWritingDialog::setupGui()
   m_infoView->setFullWidth(true);
   m_infoView->setSelectionMode( TQListView::NoSelection );
 
-  connect( m_infoView, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)),
-	   this, TQT_SLOT(slotContextMenu(KListView*, TQListViewItem*, const TQPoint&)) );
+  connect( m_infoView, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+	   this, TQ_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)) );
 
   m_writerSelectionWidget = new K3bWriterSelectionWidget( frame );
 
@@ -185,24 +185,24 @@ void K3bIsoImageWritingDialog::setupGui()
   optionTabLayout->setSpacing( spacingHint() );
   optionTabLayout->setMargin( marginHint() );
 
-  TQGroupBox* writingModeGroup = new TQGroupBox( 1,Qt::Vertical, i18n("Writing Mode"), optionTab );
+  TQGroupBox* writingModeGroup = new TQGroupBox( 1,TQt::Vertical, i18n("Writing Mode"), optionTab );
   writingModeGroup->setInsideMargin( marginHint() );
   m_writingModeWidget = new K3bWritingModeWidget( writingModeGroup );
 
 
   // copies --------
-  TQGroupBox* groupCopies = new TQGroupBox( 2, Qt::Horizontal, i18n("Copies"), optionTab );
+  TQGroupBox* groupCopies = new TQGroupBox( 2, TQt::Horizontal, i18n("Copies"), optionTab );
   groupCopies->setInsideSpacing( spacingHint() );
   groupCopies->setInsideMargin( marginHint() );
   TQLabel* pixLabel = new TQLabel( groupCopies );
-  pixLabel->setPixmap( SmallIcon( "cdcopy", KIcon::SizeMedium ) );
+  pixLabel->setPixmap( SmallIcon( "cdcopy", TDEIcon::SizeMedium ) );
   pixLabel->setScaledContents( false );
   m_spinCopies = new TQSpinBox( groupCopies );
   m_spinCopies->setMinValue( 1 );
   m_spinCopies->setMaxValue( 999 );
   // -------- copies
 
-  TQGroupBox* optionGroup = new TQGroupBox( 3,Qt::Vertical, i18n("Settings"), optionTab );
+  TQGroupBox* optionGroup = new TQGroupBox( 3,TQt::Vertical, i18n("Settings"), optionTab );
   optionGroup->setInsideMargin( marginHint() );
   optionGroup->setInsideSpacing( spacingHint() );
   m_checkDummy = K3bStdGuiItems::simulateCheckbox( optionGroup );
@@ -244,7 +244,7 @@ void K3bIsoImageWritingDialog::slotStartClicked()
 
   K3bIso9660 isoFs( imagePath() );
   if( isoFs.open() ) {
-    if( K3b::imageFilesize( KURL::fromPathOrURL( imagePath() ) ) < (KIO::filesize_t)(isoFs.primaryDescriptor().volumeSpaceSize*2048) ) {
+    if( K3b::imageFilesize( KURL::fromPathOrURL( imagePath() ) ) < (TDEIO::filesize_t)(isoFs.primaryDescriptor().volumeSpaceSize*2048) ) {
       if( KMessageBox::questionYesNo( this, 
 				      i18n("<p>This image has an invalid file size."
 					   "If it has been downloaded make sure the download is complete."
@@ -259,7 +259,7 @@ void K3bIsoImageWritingDialog::slotStartClicked()
   m_md5Job->cancel();
 
   // save the path
-  KConfig* c = k3bcore->config();
+  TDEConfig* c = k3bcore->config();
   c->setGroup( configGroup() );
   if( c->readPathEntry( "last written image" ).isEmpty() )
     c->writePathEntry( "last written image", imagePath() );
@@ -288,7 +288,7 @@ void K3bIsoImageWritingDialog::slotStartClicked()
 
   delete job;
 
-  if( KConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "keep action dialogs open", false ) &&
+  if( TDEConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "keep action dialogs open", false ) &&
       !exitLoopOnHide() )
     show();
   else
@@ -307,7 +307,7 @@ void K3bIsoImageWritingDialog::updateImageSize( const TQString& path )
   TQFileInfo info( path );
   if( info.isFile() ) {
 
-    KIO::filesize_t imageSize = K3b::filesize( KURL::fromPathOrURL(path) );
+    TDEIO::filesize_t imageSize = K3b::filesize( KURL::fromPathOrURL(path) );
 
     // ------------------------------------------------
     // Test for iso9660 image
@@ -320,10 +320,10 @@ void K3bIsoImageWritingDialog::updateImageSize( const TQString& path )
       K3bListViewItem* isoRootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 							  i18n("Iso9660 image") );
       isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
-      isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
+      isoRootItem->setPixmap( 0, SmallIcon( "application-x-cd-image") );
 
       K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
-						   i18n("Filesize:"), KIO::convertSize( imageSize ) );
+						   i18n("Filesize:"), TDEIO::convertSize( imageSize ) );
       item->setForegroundColor( 0, palette().disabled().foreground() );
 
       item = new K3bListViewItem( isoRootItem,
@@ -381,7 +381,7 @@ void K3bIsoImageWritingDialog::updateImageSize( const TQString& path )
       K3bListViewItem* item = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 				  i18n("Not an Iso9660 image") );
       item->setForegroundColor( 0, TQt::red );
-      item->setPixmap( 0, SmallIcon( "stop") );
+      item->setPixmap( 0, SmallIcon( "process-stop") );
     }
 
     calculateMd5Sum( path );
@@ -443,7 +443,7 @@ void K3bIsoImageWritingDialog::calculateMd5Sum( const TQString& file )
   d->md5SumItem->setText( 0, i18n("Md5 Sum:") );
   d->md5SumItem->setForegroundColor( 0, palette().disabled().foreground() );
   d->md5SumItem->setProgress( 1, 0 );
-  d->md5SumItem->setPixmap( 0, SmallIcon( "exec") );
+  d->md5SumItem->setPixmap( 0, SmallIcon( "application-x-executable") );
 
   if( file != d->lastCheckedFile ) {
     d->lastCheckedFile = file;
@@ -473,7 +473,7 @@ void K3bIsoImageWritingDialog::slotMd5JobFinished( bool success )
       d->md5SumItem->setText( 1, i18n("Calculation cancelled") );
     else
       d->md5SumItem->setText( 1, i18n("Calculation failed") );
-    d->md5SumItem->setPixmap( 0, SmallIcon( "stop") );
+    d->md5SumItem->setPixmap( 0, SmallIcon( "process-stop") );
     d->lastCheckedFile.truncate(0);
   }
 
@@ -481,7 +481,7 @@ void K3bIsoImageWritingDialog::slotMd5JobFinished( bool success )
 }
 
 
-void K3bIsoImageWritingDialog::slotContextMenu( KListView*, TQListViewItem*, const TQPoint& pos )
+void K3bIsoImageWritingDialog::slotContextMenu( TDEListView*, TQListViewItem*, const TQPoint& pos )
 {
   if( !d->haveMd5Sum )
     return;
@@ -514,7 +514,7 @@ void K3bIsoImageWritingDialog::slotContextMenu( KListView*, TQListViewItem*, con
 }
 
 
-void K3bIsoImageWritingDialog::loadUserDefaults( KConfigBase* c )
+void K3bIsoImageWritingDialog::loadUserDefaults( TDEConfigBase* c )
 {
   m_writingModeWidget->loadConfig( c );
   m_checkDummy->setChecked( c->readBoolEntry("simulate", false ) );
@@ -531,7 +531,7 @@ void K3bIsoImageWritingDialog::loadUserDefaults( KConfigBase* c )
 }
 
 
-void K3bIsoImageWritingDialog::saveUserDefaults( KConfigBase* c )
+void K3bIsoImageWritingDialog::saveUserDefaults( TDEConfigBase* c )
 {
   m_writingModeWidget->saveConfig( c ),
   c->writeEntry( "simulate", m_checkDummy->isChecked() );
