@@ -27,7 +27,7 @@ class KURLRequester;
   */
 class K3bMiscOptionTab : public base_K3bMiscOptionTab
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 
  public: 
