@@ -84,8 +84,8 @@ K3bDataBurnDialog::K3bDataBurnDialog(K3bDataDoc* _doc, TQWidget *parent, const c
 
   setupSettingsTab();
 
-  connect( m_comboMultisession, TQT_SIGNAL(activated(int)),
-	   this, TQT_SLOT(slotMultiSessionModeChanged()) );
+  connect( m_comboMultisession, TQ_SIGNAL(activated(int)),
+	   this, TQ_SLOT(slotMultiSessionModeChanged()) );
 
   m_writerSelectionWidget->setWantedMediumState( K3bDevice::STATE_EMPTY|K3bDevice::STATE_INCOMPLETE );
 
@@ -98,8 +98,8 @@ K3bDataBurnDialog::K3bDataBurnDialog(K3bDataDoc* _doc, TQWidget *parent, const c
       m_tempDirSelectionWidget->setDefaultImageFileName( _doc->isoOptions().volumeID() + ".iso" );
   }
 
-  connect( m_imageSettingsWidget->m_editVolumeName, TQT_SIGNAL(textChanged(const TQString&)),
-           m_tempDirSelectionWidget, TQT_SLOT(setDefaultImageFileName(const TQString&)) );
+  connect( m_imageSettingsWidget->m_editVolumeName, TQ_SIGNAL(textChanged(const TQString&)),
+           m_tempDirSelectionWidget, TQ_SLOT(setDefaultImageFileName(const TQString&)) );
 }
 
 K3bDataBurnDialog::~K3bDataBurnDialog()
@@ -157,10 +157,10 @@ void K3bDataBurnDialog::setupSettingsTab()
   frameLayout->setSpacing( spacingHint() );
   frameLayout->setMargin( marginHint() );
 
-  m_groupDataMode = new TQGroupBox( 1, Qt::Vertical, i18n("Datatrack Mode"), frame );
+  m_groupDataMode = new TQGroupBox( 1, TQt::Vertical, i18n("Datatrack Mode"), frame );
   m_dataModeWidget = new K3bDataModeWidget( m_groupDataMode );
 
-  TQGroupBox* groupMultiSession = new TQGroupBox( 1, Qt::Vertical, i18n("Multisession Mode"), frame );
+  TQGroupBox* groupMultiSession = new TQGroupBox( 1, TQt::Vertical, i18n("Multisession Mode"), frame );
   m_comboMultisession = new K3bDataMultiSessionCombobox( groupMultiSession );
 
   frameLayout->addWidget( m_groupDataMode, 0, 0 );
