@@ -46,7 +46,7 @@ class TQDragLeaveEvent;
 
 class K3bDataFileView : public K3bListView  
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
