@@ -28,7 +28,7 @@ class TQHideEvent;
 
 class K3bVideoDVDRippingTitleListView : public K3bListView
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
